@@ -1,11 +1,5 @@
-# -*- coding: utf-8 -*-
-#
-# Copyright 2021-2024 Nitrokey Developers
-#
-# Licensed under the Apache License, Version 2.0, <LICENSE-APACHE or
-# http://apache.org/licenses/LICENSE-2.0> or the MIT license <LICENSE-MIT or
-# http://opensource.org/licenses/MIT>, at your option. This file may not be
-# copied, modified, or distributed except according to those terms.
+# Copyright Nitrokey GmbH
+# SPDX-License-Identifier: Apache-2.0 OR MIT
 
 import logging
 import os.path
@@ -63,16 +57,13 @@ class Context(ABC, Generic[Bootloader, Device]):
 
     @property
     @abstractmethod
-    def test_cases(self) -> Sequence[TestCase]:
-        ...
+    def test_cases(self) -> Sequence[TestCase]: ...
 
     @abstractmethod
-    def open(self, path: str) -> Optional[TrussedBase]:
-        ...
+    def open(self, path: str) -> Optional[TrussedBase]: ...
 
     @abstractmethod
-    def list_all(self) -> Sequence[TrussedBase]:
-        ...
+    def list_all(self) -> Sequence[TrussedBase]: ...
 
     def list(self) -> Sequence[TrussedBase]:
         if self.path:
